@@ -79,7 +79,7 @@ class Lang:
         cur_thread = threading.currentThread()
         if hasattr(cur_thread, "lang"):
             return cur_thread.lang
-        return env.get("LANG", "en_US.UTF-8").split('.')[0].split("_")[0]
+        return env.get("LANG", "en_US.utf8").split('.')[0].split("_")[0]
 
     def __gettranslate(self):
         l = self.get_current_lang()
