@@ -69,7 +69,8 @@ class InitrdFile(object):
     def get_names(self):
         if not path.exists(self._file):
             # raise IOError
-            open(self._file)
+            with open(self._file, 'r'):
+                pass
         buftype = typeFile(magic=0x4).getMTypeBuf
         rdtype = buftype(self.skipcpio_data(self._file))
         if "LZ4" in rdtype:
